@@ -15,25 +15,6 @@ if 'READTHEDOCS' in os.environ:
         sys.modules['smarkets.seto'] = sys.modules['smarkets.seto.piqi_pb2'] = Mock()
 
 from smarkets.clients import Smarkets  # noqa
-from smarkets.events import (  # noqa
-    EventsRequest,
-    Politics,
-    CurrentAffairs,
-    TvAndEntertainment,
-    SportByDate,
-    FootballByDate,
-    HorseRacingByDate,
-    TennisByDate,
-    BasketballByDate,
-    AmericanFootballByDate,
-    BaseballByDate,
-    CricketByDate,
-    HandballByDate,
-    RugbyByDate,
-    RugbyLeagueByDate,
-    VolleyballByDate,
-    SportOther,
-)
 from smarkets.exceptions import (  # noqa
     Error,
     ConnectionError,
@@ -46,7 +27,7 @@ from smarkets.orders import OrderCreate  # noqa
 from smarkets.sessions import Session, SessionSettings  # noqa
 
 
-__version__ = '0.4.14'
+__version__ = '0.4.15'
 
 __all__ = sorted(name for name, obj in locals().items()
                  if not (name.startswith('_') or inspect.ismodule(obj)))
